--- nginx-1.2.7.orig/src/http/modules/ngx_http_limit_req_module.c	2012-09-24 19:11:45.000000000 +0000
+++ nginx-1.2.7/src/http/modules/ngx_http_limit_req_module.c	2013-03-02 01:19:34.490398983 +0000
@@ -46,6 +46,9 @@
     /* integer value, 1 corresponds to 0.001 r/s */
     ngx_uint_t                   burst;
     ngx_uint_t                   nodelay; /* unsigned  nodelay:1 */
+    /* Status code to return when limit is exceeded.
+       Defaults to NGX_HTTP_SERVICE_UNAVAILABLE */
+    ngx_uint_t                   status_code; 
 } ngx_http_limit_req_limit_t;
 
 
@@ -94,7 +97,7 @@
       NULL },
 
     { ngx_string("limit_req"),
-      NGX_HTTP_MAIN_CONF|NGX_HTTP_SRV_CONF|NGX_HTTP_LOC_CONF|NGX_CONF_TAKE123,
+      NGX_HTTP_MAIN_CONF|NGX_HTTP_SRV_CONF|NGX_HTTP_LOC_CONF|NGX_CONF_TAKE1234,
       ngx_http_limit_req,
       NGX_HTTP_LOC_CONF_OFFSET,
       0,
@@ -245,7 +248,7 @@
             ctx->node = NULL;
         }
 
-        return NGX_HTTP_SERVICE_UNAVAILABLE;
+        return limit->status_code;
     }
 
     /* rc == NGX_AGAIN || rc == NGX_OK */
@@ -857,7 +860,7 @@
 
     ngx_int_t                    burst;
     ngx_str_t                   *value, s;
-    ngx_uint_t                   i, nodelay;
+    ngx_uint_t                   i, nodelay, status_code;
     ngx_shm_zone_t              *shm_zone;
     ngx_http_limit_req_limit_t  *limit, *limits;
 
@@ -866,6 +869,7 @@
     shm_zone = NULL;
     burst = 0;
     nodelay = 0;
+    status_code = NGX_HTTP_SERVICE_UNAVAILABLE;
 
     for (i = 1; i < cf->args->nelts; i++) {
 
@@ -900,6 +904,18 @@
             continue;
         }
 
+        if (ngx_strncmp(value[i].data, "status_code=", 12) == 0) {
+
+            status_code = ngx_atoi(value[i].data + 12, value[i].len - 12);
+            if (status_code > 599 || status_code < 400) {
+                ngx_conf_log_error(NGX_LOG_EMERG, cf, 0,
+                                   "invalid status_code \"%V\"", &value[i]);
+                return NGX_CONF_ERROR;
+            }
+
+            continue;
+        }
+
         ngx_conf_log_error(NGX_LOG_EMERG, cf, 0,
                            "invalid parameter \"%V\"", &value[i]);
         return NGX_CONF_ERROR;
@@ -944,6 +960,7 @@
     limit->shm_zone = shm_zone;
     limit->burst = burst * 1000;
     limit->nodelay = nodelay;
+    limit->status_code = status_code;
 
     return NGX_CONF_OK;
 }
